--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "geodetic_datum" VALUES('EPSG','1024','Hungarian Datum 1909',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1119',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1025','Taiwan Datum 1967',NULL,NULL,'EPSG','7050','EPSG','8901','EPSG','3315',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1026','Taiwan Datum 1997',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1228',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1029','Iraqi Geospatial Reference System',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1124',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1031','MGI 1901',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','2370',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1032','MOLDREF99',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1162',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1033','Reseau Geodesique de la RDC 2005',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3613',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1034','Serbian Reference Network 1998',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4543',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1035','Red Geodesica de Canarias 1995',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3199',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1036','Reseau Geodesique de Mayotte 2004',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1159',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1037','Cadastre 1997',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3340',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1038','Reseau Geodesique de Saint Pierre et Miquelon 2006',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1220',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1041','Autonomous Regions of Portugal 2008',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3670',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1042','Mexico ITRF92',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1160',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1043','China 2000',NULL,NULL,'EPSG','1024','EPSG','8901','EPSG','1067',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1044','Sao Tome',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3645',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1045','New Beijing',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','3228',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1046','Principe',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3646',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1047','Reseau de Reference des Antilles Francaises 1991',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','2824',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1048','Tokyo 1892',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1364',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1052','System of the Unified Trigonometrical Cadastral Network/05',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1079',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1053','Sri Lanka Datum 1999',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','3310',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1055','System of the Unified Trigonometrical Cadastral Network/05 (Ferro)',NULL,NULL,'EPSG','7004','EPSG','8909','EPSG','1079',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1056','Geocentric Datum Brunei Darussalam 2009',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1055',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1057','Turkish National Reference Frame',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1237',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1058','Bhutan National Geodetic Datum',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1048',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1060','Islands Net 2004',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1120',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1061','International Terrestrial Reference Frame 2008',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1062','Posiciones Geodesicas Argentinas 2007',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1033',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1063','Marco Geodesico Nacional de Bolivia',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1049',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1064','SIRGAS-Chile realization 1 epoch 2002',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1066',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1065','Costa Rica 2005',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1074',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1066','Sistema Geodesico Nacional de Panama MACARIO SOLIS',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1186',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1067','Peru96',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1189',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1068','SIRGAS-ROU98',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1247',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1069','SIRGAS_ES2007.8',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1087',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1070','Ocotepeque 1935',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3876',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1071','Sibun Gorge 1922',NULL,NULL,'EPSG','7007','EPSG','8901','EPSG','3219',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1072','Panama-Colon 1911',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3290',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1073','Reseau Geodesique des Antilles Francaises 2009',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','2824',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1074','Corrego Alegre 1961',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3874',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1075','South American Datum 1969(96)',NULL,NULL,'EPSG','7050','EPSG','8901','EPSG','1053',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1076','Papua New Guinea Geodetic Datum 1994',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1187',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1077','Ukraine 2000',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1242',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1078','Fehmarnbelt Datum 2010',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3889',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1081','Deutsche Bahn Reference System',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','3339',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1095','Tonga Geodetic Datum 2005',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1234',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1100','Cayman Islands Geodetic Datum 2011',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1063',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1111','Nepal 1981',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','1171',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1112','Cyprus Geodetic Reference System 1993',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','3236',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1113','Reseau Geodesique des Terres Australes et Antarctiques Francaises 2007',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4246',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1114','Israeli Geodetic Datum 2005',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1126',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1115','Israeli Geodetic Datum 2005(2012)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1126',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1116','NAD83 (National Spatial Reference System 2011)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1511',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1117','NAD83 (National Spatial Reference System PA11)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4162',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1118','NAD83 (National Spatial Reference System MA11)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4167',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1120','Mexico ITRF2008',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1160',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1128','Japanese Geodetic Datum 2011',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1129',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1132','Rete Dinamica Nazionale 2008',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3343',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1133','NAD83 (Continuously Operating Reference Station 1996)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1511',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1135','Aden 1925',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1340',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1136','Bioko',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','4220',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1137','Bekaa Valley 1920',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3269',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1138','South East Island 1943',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','4183',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1139','Gambia',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3250',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1141','IGS08',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1142','IG05 Intermediate Datum',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','2603',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1143','Israeli Geodetic Datum 2005',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1126',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','1144','IG05/12 Intermediate Datum',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','2603',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1145','Israeli Geodetic Datum 2005(2012)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1126',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','1147','Oman National Geodetic Datum 2014',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1183',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1152','World Geodetic System 1984 (G730)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1153','World Geodetic System 1984 (G873)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1154','World Geodetic System 1984 (G1150)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1155','World Geodetic System 1984 (G1674)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1156','World Geodetic System 1984 (G1762)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1157','Parametry Zemli 1990.02',NULL,NULL,'EPSG','7054','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1158','Parametry Zemli 1990.11',NULL,NULL,'EPSG','7054','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1159','Geodezicheskaya Sistema Koordinat 2011',NULL,NULL,'EPSG','1025','EPSG','8901','EPSG','1198',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1160','Kyrgyzstan Geodetic Datum 2006',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1137',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1165','International Terrestrial Reference Frame 2014',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1166','World Geodetic System 1984 (Transit)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1167','Bulgaria Geodetic System 2005',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1056',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1168','Geocentric Datum of Australia 2020',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4177',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1173','St. Helena Tritan',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','3183',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1174','St. Helena Geodetic Datum 2015',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3183',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1178','European Terrestrial Reference Frame 1989',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1179','European Terrestrial Reference Frame 1990',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1180','European Terrestrial Reference Frame 1991',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1181','European Terrestrial Reference Frame 1992',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1182','European Terrestrial Reference Frame 1993',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1183','European Terrestrial Reference Frame 1994',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1184','European Terrestrial Reference Frame 1996',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1185','European Terrestrial Reference Frame 1997',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1186','European Terrestrial Reference Frame 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1187','Islands Net 2016',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1120',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1188','Gusterberg (Ferro)',NULL,NULL,'EPSG','1026','EPSG','8909','EPSG','4455',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1189','St. Stephen (Ferro)',NULL,NULL,'EPSG','1026','EPSG','8909','EPSG','4456',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1191','IGS14',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1192','North American Datum of 1983 (CSRS96)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1193','North American Datum of 1983 (CSRS) version 2',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1194','North American Datum of 1983 (CSRS) version 3',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1195','North American Datum of 1983 (CSRS) version 4',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1196','North American Datum of 1983 (CSRS) version 5',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1197','North American Datum of 1983 (CSRS) version 6',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1198','North American Datum of 1983 (CSRS) version 7',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1201','System of the Unified Trigonometrical Cadastral Network [JTSK03]',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1211',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1204','European Terrestrial Reference Frame 2005',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1206','European Terrestrial Reference Frame 2014',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1207','Macao 1920',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1147',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1208','Macao Geodetic Datum 2008',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1147',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1209','Hong Kong Geodetic',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1118',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1211','NAD83 (Federal Base Network)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4515',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1212','NAD83 (High Accuracy Reference Network - Corrected)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3634',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1214','Serbian Spatial Reference System 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4543',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1217','Camacupa 2015',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1029',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1218','MOMRA Terrestrial Reference Frame 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1206',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1220','Reference System de Angola 2013',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1029',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1221','North American Datum of 1983 (MARP00)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4167',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1223','Reseau Geodesique de Wallis et Futuna 1996',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1255',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1225','CR-SIRGAS',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1074',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1227','SIRGAS Continuously Operating Network DGF00P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1228','SIRGAS Continuously Operating Network DGF01P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1229','SIRGAS Continuously Operating Network DGF01P02',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1230','SIRGAS Continuously Operating Network DGF02P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1231','SIRGAS Continuously Operating Network DGF04P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1232','SIRGAS Continuously Operating Network DGF05P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1233','SIRGAS Continuously Operating Network DGF06P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1234','SIRGAS Continuously Operating Network DGF07P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1235','SIRGAS Continuously Operating Network DGF08P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1236','SIRGAS Continuously Operating Network SIR09P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1237','SIRGAS Continuously Operating Network SIR10P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1238','SIRGAS Continuously Operating Network SIR11P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1239','SIRGAS Continuously Operating Network SIR13P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1240','SIRGAS Continuously Operating Network SIR14P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1241','SIRGAS Continuously Operating Network SIR15P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1242','SIRGAS Continuously Operating Network SIR17P01',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1243','SIRGAS-Chile realization 2 epoch 2010.00',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1066',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1244','IGS97',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1245','IGS00',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1246','IGb00',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1247','IGS05',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1248','IGb08',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1249','North American Datum of 1983 (PACP00)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4162',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1251','Kosovo Reference System 2001',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4542',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1252','SIRGAS-Chile realization 3 epoch 2013.00',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1066',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1253','SIRGAS-Chile realization 4 epoch 2016.00',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1066',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','1254','SIRGAS-Chile',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1066',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6001','Not specified (based on Airy 1830 ellipsoid)',NULL,NULL,'EPSG','7001','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6002','Not specified (based on Airy Modified 1849 ellipsoid)',NULL,NULL,'EPSG','7002','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6003','Not specified (based on Australian National Spheroid)',NULL,NULL,'EPSG','7003','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6004','Not specified (based on Bessel 1841 ellipsoid)',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6005','Not specified (based on Bessel Modified ellipsoid)',NULL,NULL,'EPSG','7005','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6006','Not specified (based on Bessel Namibia ellipsoid)',NULL,NULL,'EPSG','7046','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6007','Not specified (based on Clarke 1858 ellipsoid)',NULL,NULL,'EPSG','7007','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6008','Not specified (based on Clarke 1866 ellipsoid)',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6009','Not specified (based on Clarke 1866 Michigan ellipsoid)',NULL,NULL,'EPSG','7009','EPSG','8901','EPSG','1263',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6010','Not specified (based on Clarke 1880 (Benoit) ellipsoid)',NULL,NULL,'EPSG','7010','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6011','Not specified (based on Clarke 1880 (IGN) ellipsoid)',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6012','Not specified (based on Clarke 1880 (RGS) ellipsoid)',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6013','Not specified (based on Clarke 1880 (Arc) ellipsoid)',NULL,NULL,'EPSG','7013','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6014','Not specified (based on Clarke 1880 (SGA 1922) ellipsoid)',NULL,NULL,'EPSG','7014','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6015','Not specified (based on Everest 1830 (1937 Adjustment) ellipsoid)',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6016','Not specified (based on Everest 1830 (1967 Definition) ellipsoid)',NULL,NULL,'EPSG','7016','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6018','Not specified (based on Everest 1830 Modified ellipsoid)',NULL,NULL,'EPSG','7018','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6019','Not specified (based on GRS 1980 ellipsoid)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6020','Not specified (based on Helmert 1906 ellipsoid)',NULL,NULL,'EPSG','7020','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6021','Not specified (based on Indonesian National Spheroid)',NULL,NULL,'EPSG','7021','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6022','Not specified (based on International 1924 ellipsoid)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6024','Not specified (based on Krassowsky 1940 ellipsoid)',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6025','Not specified (based on NWL 9D ellipsoid)',NULL,NULL,'EPSG','7025','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6027','Not specified (based on Plessis 1817 ellipsoid)',NULL,NULL,'EPSG','7027','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6028','Not specified (based on Struve 1860 ellipsoid)',NULL,NULL,'EPSG','7028','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6029','Not specified (based on War Office ellipsoid)',NULL,NULL,'EPSG','7029','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6030','Not specified (based on WGS 84 ellipsoid)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6031','Not specified (based on GEM 10C ellipsoid)',NULL,NULL,'EPSG','7031','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6032','Not specified (based on OSU86F ellipsoid)',NULL,NULL,'EPSG','7032','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6033','Not specified (based on OSU91A ellipsoid)',NULL,NULL,'EPSG','7033','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6034','Not specified (based on Clarke 1880 ellipsoid)',NULL,NULL,'EPSG','7034','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6035','Not specified (based on Authalic Sphere)',NULL,NULL,'EPSG','7035','EPSG','8901','EPSG','1263',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6036','Not specified (based on GRS 1967 ellipsoid)',NULL,NULL,'EPSG','7036','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6041','Not specified (based on Average Terrestrial System 1977 ellipsoid)',NULL,NULL,'EPSG','7041','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6042','Not specified (based on Everest (1830 Definition) ellipsoid)',NULL,NULL,'EPSG','7042','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6043','Not specified (based on WGS 72 ellipsoid)',NULL,NULL,'EPSG','7043','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6044','Not specified (based on Everest 1830 (1962 Definition) ellipsoid)',NULL,NULL,'EPSG','7044','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6045','Not specified (based on Everest 1830 (1975 Definition) ellipsoid)',NULL,NULL,'EPSG','7045','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6047','Not specified (based on GRS 1980 Authalic Sphere)',NULL,NULL,'EPSG','7048','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6052','Not specified (based on Clarke 1866 Authalic Sphere)',NULL,NULL,'EPSG','7052','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6053','Not specified (based on International 1924 Authalic Sphere)',NULL,NULL,'EPSG','7057','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6054','Not specified (based on Hughes 1980 ellipsoid)',NULL,NULL,'EPSG','7058','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6055','Popular Visualisation Datum',NULL,NULL,'EPSG','7059','EPSG','8901','EPSG','1262',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6120','Greek',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','3254',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6121','Greek Geodetic Reference System 1987',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3254',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6122','Average Terrestrial System 1977',NULL,NULL,'EPSG','7041','EPSG','8901','EPSG','1283',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6123','Kartastokoordinaattijarjestelma (1966)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3333',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6124','Rikets koordinatsystem 1990',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1225',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6125','Samboja',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1328',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6126','Lithuania 1994 (ETRS89)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1145',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6127','Tete',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3281',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6128','Madzansua',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1315',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6129','Observatario',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1329',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6130','Moznet (ITRF94)',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1167',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6131','Indian 1960',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','4007',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6132','Final Datum 1958',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1300',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6133','Estonia 1992',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3246',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6134','PDO Survey Datum 1993',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3288',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6135','Old Hawaiian',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1334',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6136','St. Lawrence Island',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1332',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6137','St. Paul Island',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1333',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6138','St. George Island',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1331',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6139','Puerto Rico',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1335',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6140','NAD83 Canadian Spatial Reference System',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1061',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6141','Israel 1993',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','2603',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6142','Locodjo 1965',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1075',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6143','Abidjan 1987',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1075',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6144','Kalianpur 1937',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','1308',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6145','Kalianpur 1962',NULL,NULL,'EPSG','7044','EPSG','8901','EPSG','1184',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6146','Kalianpur 1975',NULL,NULL,'EPSG','7045','EPSG','8901','EPSG','3341',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6147','Hanoi 1972',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','3328',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6148','Hartebeesthoek94',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','4540',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6149','CH1903',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1286',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6150','CH1903+',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1286',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6151','Swiss Terrestrial Reference Frame 1995',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1286',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6152','NAD83 (High Accuracy Reference Network)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1337',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6153','Rassadiran',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1338',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6154','European Datum 1950(1977)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1123',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6155','Dabola 1981',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','3257',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6156','System of the Unified Trigonometrical Cadastral Network',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1306',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6157','Mount Dillon',NULL,NULL,'EPSG','7007','EPSG','8901','EPSG','1322',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6158','Naparima 1955',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3143',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6159','European Libyan Datum 1979',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1143',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6160','Chos Malal 1914',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1292',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6161','Pampa del Castillo',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1265',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6162','Korean Datum 1985',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','3266',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6163','Yemen National Geodetic Network 1996',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1257',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6164','South Yemen',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1340',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6165','Bissau',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3258',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6166','Korean Datum 1995',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','3266',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6167','New Zealand Geodetic Datum 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1175',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6168','Accra',NULL,NULL,'EPSG','7029','EPSG','8901','EPSG','1104',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6169','American Samoa 1962',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3109',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6170','Sistema de Referencia Geocentrico para America del Sur 1995',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3448',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6171','Reseau Geodesique Francais 1993',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1096',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6172','Posiciones Geodesicas Argentinas',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1033',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6173','IRENET95',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1305',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6174','Sierra Leone Colony 1924',NULL,NULL,'EPSG','7029','EPSG','8901','EPSG','1342',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6175','Sierra Leone 1968',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3306',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6176','Australian Antarctic Datum 1998',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1278',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6178','Pulkovo 1942(83)',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','3900',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6179','Pulkovo 1942(58)',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','3574',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6180','Estonia 1997',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1090',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6181','Luxembourg 1930',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1146',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6182','Azores Occidental Islands 1939',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1344',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6183','Azores Central Islands 1948',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1301',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6184','Azores Oriental Islands 1940',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1345',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6185','Madeira 1936',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1314',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6188','OSNI 1952',NULL,NULL,'EPSG','7001','EPSG','8901','EPSG','2530',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6189','Red Geodesica Venezolana',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1251',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6190','Posiciones Geodesicas Argentinas 1998',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1033',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6191','Albanian 1987',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','3212',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6192','Douala 1948',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2555',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6193','Manoca 1962',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','2555',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6194','Qornoq 1927',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3362',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6195','Scoresbysund 1952',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2570',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6196','Ammassalik 1958',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2571',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6197','Garoua',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','2590',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6198','Kousseri',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','2591',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6199','Egypt 1930',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3242',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6200','Pulkovo 1995',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1198',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6201','Adindan',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1271',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6202','Australian Geodetic Datum 1966',NULL,NULL,'EPSG','7003','EPSG','8901','EPSG','1279',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6203','Australian Geodetic Datum 1984',NULL,NULL,'EPSG','7003','EPSG','8901','EPSG','2576',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6204','Ain el Abd 1970',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1272',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6205','Afgooye',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','3308',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6206','Agadez',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1177',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6207','Lisbon 1937',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1294',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6208','Aratu',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1274',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6209','Arc 1950',NULL,NULL,'EPSG','7013','EPSG','8901','EPSG','1276',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6210','Arc 1960',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1277',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6211','Batavia',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','3666',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6212','Barbados 1938',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3218',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6213','Beduaram',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','2771',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6214','Beijing 1954',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1067',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6215','Reseau National Belge 1950',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1347',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6216','Bermuda 1957',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3221',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6218','Bogota 1975',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3686',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6219','Bukit Rimpah',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1287',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6220','Camacupa 1948',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1288',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6221','Campo Inchauspe',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3843',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6222','Cape',NULL,NULL,'EPSG','7013','EPSG','8901','EPSG','1290',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6223','Carthage',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1236',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6224','Chua',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3356',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6225','Corrego Alegre 1970-72',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1293',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6226','Cote d''Ivoire',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1075',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6227','Deir ez Zor',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1623',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6228','Douala',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1060',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6229','Egypt 1907',NULL,NULL,'EPSG','7020','EPSG','8901','EPSG','1086',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6230','European Datum 1950',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1296',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6231','European Datum 1987',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1297',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6232','Fahud',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','4009',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6233','Gandajika 1970',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1152',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6234','Garoua',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1060',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6235','Guyane Francaise',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1097',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6236','Hu Tzu Shan 1950',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3315',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6237','Hungarian Datum 1972',NULL,NULL,'EPSG','7036','EPSG','8901','EPSG','1119',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6238','Indonesian Datum 1974',NULL,NULL,'EPSG','7021','EPSG','8901','EPSG','4020',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6239','Indian 1954',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','1304',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6240','Indian 1975',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','3741',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6241','Jamaica 1875',NULL,NULL,'EPSG','7034','EPSG','8901','EPSG','3342',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6242','Jamaica 1969',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3342',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6243','Kalianpur 1880',NULL,NULL,'EPSG','7042','EPSG','8901','EPSG','1307',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6244','Kandawala',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','3310',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6245','Kertau 1968',NULL,NULL,'EPSG','7018','EPSG','8901','EPSG','4223',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6246','Kuwait Oil Company',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3267',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6247','La Canoa',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3327',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6248','Provisional South American Datum 1956',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1348',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6249','Lake',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1312',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6250','Leigon',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1104',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6251','Liberia 1964',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3270',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6252','Lome',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1232',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6253','Luzon 1911',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3969',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6254','Hito XVIII 1963',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1303',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6255','Herat North',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1024',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6256','Mahe 1971',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','2369',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6257','Makassar',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1316',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6258','European Terrestrial Reference System 1989',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6259','Malongo 1987',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3180',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6260','Manoca',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1060',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6261','Merchich',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','3280',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6262','Massawa',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1089',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6263','Minna',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1178',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6264','Mhast',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1318',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6265','Monte Mario',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3343',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6266','M''poraloko',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1100',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6267','North American Datum 1927',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1349',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6268','NAD27 Michigan',NULL,NULL,'EPSG','7009','EPSG','8901','EPSG','1391',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6269','North American Datum 1983',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1350',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6270','Nahrwan 1967',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1351',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6271','Naparima 1972',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1322',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6272','New Zealand Geodetic Datum 1949',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3285',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6273','NGO 1948',NULL,NULL,'EPSG','7005','EPSG','8901','EPSG','1352',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6274','Datum 73',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1294',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6275','Nouvelle Triangulation Francaise',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','3694',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6276','NSWC 9Z-2',NULL,NULL,'EPSG','7025','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6277','OSGB 1936',NULL,NULL,'EPSG','7001','EPSG','8901','EPSG','4390',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6278','OSGB 1970 (SN)',NULL,NULL,'EPSG','7001','EPSG','8901','EPSG','1264',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6279','OS (SN) 1980',NULL,NULL,'EPSG','7001','EPSG','8901','EPSG','1354',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6280','Padang 1884',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1355',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6281','Palestine 1923',NULL,NULL,'EPSG','7010','EPSG','8901','EPSG','1356',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6282','Congo 1960 Pointe Noire',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1072',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6283','Geocentric Datum of Australia 1994',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','4177',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6284','Pulkovo 1942',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','2423',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6285','Qatar 1974',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1195',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6286','Qatar 1948',NULL,NULL,'EPSG','7020','EPSG','8901','EPSG','1346',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6287','Qornoq',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1107',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6288','Loma Quintana',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1313',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6289','Amersfoort',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1275',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6291','South American Datum 1969',NULL,NULL,'EPSG','7036','EPSG','8901','EPSG','1358',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6292','Sapper Hill 1943',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3247',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6293','Schwarzeck',NULL,NULL,'EPSG','7046','EPSG','8901','EPSG','1169',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6294','Segora',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1359',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6295','Serindung',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','4005',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6296','Sudan',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1361',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6297','Tananarive 1925',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1149',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6298','Timbalai 1948',NULL,NULL,'EPSG','7016','EPSG','8901','EPSG','1362',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6299','TM65',NULL,NULL,'EPSG','7002','EPSG','8901','EPSG','1305',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6300','Geodetic Datum of 1965',NULL,NULL,'EPSG','7002','EPSG','8901','EPSG','1305',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6301','Tokyo',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1364',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6302','Trinidad 1903',NULL,NULL,'EPSG','7007','EPSG','8901','EPSG','1339',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6303','Trucial Coast 1948',NULL,NULL,'EPSG','7020','EPSG','8901','EPSG','1363',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6304','Voirol 1875',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1365',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6306','Bern 1938',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1286',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6307','Nord Sahara 1959',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1026',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6308','Stockholm 1938',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','3313',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6309','Yacare',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3326',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6310','Yoff',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1207',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6311','Zanderij',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1222',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6312','Militar-Geographische Institut',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1037',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6313','Reseau National Belge 1972',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1347',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6314','Deutsches Hauptdreiecksnetz',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','2326',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6315','Conakry 1905',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','3257',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6316','Dealul Piscului 1930',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3295',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6317','Dealul Piscului 1970',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1197',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6318','National Geodetic Network',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','3267',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6319','Kuwait Utility',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1310',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6322','World Geodetic System 1972',NULL,NULL,'EPSG','7043','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6324','WGS 72 Transit Broadcast Ephemeris',NULL,NULL,'EPSG','7043','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6326','World Geodetic System 1984',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6600','Anguilla 1957',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3214',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6601','Antigua 1943',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1273',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6602','Dominica 1945',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3239',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6603','Grenada 1953',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1551',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6604','Montserrat 1958',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3279',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6605','St. Kitts 1955',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3297',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6606','St. Lucia 1955',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3298',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6607','St. Vincent 1945',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3300',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6608','North American Datum 1927 (1976)',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1367',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6609','North American Datum 1927 (CGQ77)',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1368',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6610','Xian 1980',NULL,NULL,'EPSG','7049','EPSG','8901','EPSG','3228',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6611','Hong Kong 1980',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1118',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6612','Japanese Geodetic Datum 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1129',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6613','Gunung Segara',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1360',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6614','Qatar National Datum 1995',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1346',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6615','Porto Santo 1936',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1314',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6616','Selvagem Grande',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2779',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6618','South American Datum 1969',NULL,NULL,'EPSG','7050','EPSG','8901','EPSG','1358',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6619','SWEREF99',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1225',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6620','Point 58',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','2790',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6621','Fort Marigot',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2828',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6622','Guadeloupe 1948',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2829',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6623','Centre Spatial Guyanais 1967',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3105',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6624','Reseau Geodesique Francais Guyane 1995',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1097',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6625','Martinique 1938',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3276',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6626','Reunion 1947',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3337',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6627','Reseau Geodesique de la Reunion 1992',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3902',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6628','Tahiti 52',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2811',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6629','Tahaa 54',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2812',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6630','IGN72 Nuku Hiva',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3129',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6631','K0 1949',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2816',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6632','Combani 1950',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3340',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6633','IGN56 Lifou',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2814',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6634','IGN72 Grande Terre',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2822',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6635','ST87 Ouvea',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2813',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6636','Petrels 1972',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2817',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6637','Pointe Geologie Perroud 1950',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2818',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6638','Saint Pierre et Miquelon 1950',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3299',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6639','MOP78',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2815',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6640','Reseau de Reference des Antilles Francaises 1991',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','2824',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6641','IGN53 Mare',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2819',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6642','ST84 Ile des Pins',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2820',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6643','ST71 Belep',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2821',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6644','NEA74 Noumea',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2823',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6645','Reseau Geodesique Nouvelle Caledonie 1991',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1174',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6646','Grand Comoros',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2807',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6647','International Terrestrial Reference Frame 1988',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6648','International Terrestrial Reference Frame 1989',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6649','International Terrestrial Reference Frame 1990',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6650','International Terrestrial Reference Frame 1991',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6651','International Terrestrial Reference Frame 1992',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6652','International Terrestrial Reference Frame 1993',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6653','International Terrestrial Reference Frame 1994',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6654','International Terrestrial Reference Frame 1996',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6655','International Terrestrial Reference Frame 1997',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6656','International Terrestrial Reference Frame 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6657','Reykjavik 1900',NULL,NULL,'EPSG','7051','EPSG','8901','EPSG','3262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6658','Hjorsey 1955',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6659','Islands Net 1993',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1120',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6660','Helle 1954',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2869',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6661','Latvia 1992',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1139',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6663','Porto Santo 1995',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1314',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6664','Azores Oriental Islands 1995',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1345',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6665','Azores Central Islands 1995',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1301',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6666','Lisbon 1890',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','1294',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6667','Iraq-Kuwait Boundary Datum 1992',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','2876',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6668','European Datum 1979',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1297',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6670','Istituto Geografico Militaire 1995',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','3343',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6671','Voirol 1879',NULL,NULL,'EPSG','7011','EPSG','8901','EPSG','1365',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6672','Chatham Islands Datum 1971',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2889',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6673','Chatham Islands Datum 1979',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2889',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6674','Sistema de Referencia Geocentrico para las AmericaS 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3418',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6675','Guam 1963',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','4525',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6676','Vientiane 1982',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1138',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6677','Lao 1993',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1138',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6678','Lao National Datum 1997',NULL,NULL,'EPSG','7024','EPSG','8901','EPSG','1138',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6679','Jouik 1961',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','2967',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6680','Nouakchott 1965',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','2968',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6681','Mauritania 1999',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1157',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6682','Gulshan 303',NULL,NULL,'EPSG','7015','EPSG','8901','EPSG','1041',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6683','Philippine Reference System 1992',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','1190',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6684','Gan 1970',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3274',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6685','Gandajika',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1259',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6686','Marco Geocentrico Nacional de Referencia',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1070',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6687','Reseau Geodesique de la Polynesie Francaise',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1098',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6688','Fatu Iva 72',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3133',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6689','IGN63 Hiva Oa',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3130',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6690','Tahiti 79',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3124',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6691','Moorea 87',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3125',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6692','Maupiti 83',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3126',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6693','Nakhl-e Ghanem',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','2362',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6694','Posiciones Geodesicas Argentinas 1994',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1033',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6695','Katanga 1955',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3147',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6696','Kasai 1953',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3148',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6697','IGC 1962 Arc of the 6th Parallel South',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3149',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6698','IGN 1962 Kerguelen',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','2816',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6699','Le Pouce 1934',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3209',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6700','IGN Astro 1960',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3277',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6701','Institut Geographique du Congo Belge 1955',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3171',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6702','Mauritania 1999',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1157',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6703','Missao Hidrografico Angola y Sao Tome 1951',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1318',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6704','Mhast (onshore)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3179',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6705','Mhast (offshore)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3180',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6706','Egypt Gulf of Suez S-650 TL',NULL,NULL,'EPSG','7020','EPSG','8901','EPSG','2341',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6707','Tern Island 1961',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3181',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6708','Cocos Islands 1965',NULL,NULL,'EPSG','7003','EPSG','8901','EPSG','1069',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6709','Iwo Jima 1945',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3200',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6710','Astro DOS 71',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3183',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6711','Marcus Island 1952',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1872',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6712','Ascension Island 1958',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3182',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6713','Ayabelle Lighthouse',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','1081',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6714','Bellevue',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3193',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6715','Camp Area Astro',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3205',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6716','Phoenix Islands 1966',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3196',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6717','Cape Canaveral',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3206',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6718','Solomon 1968',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1213',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6719','Easter Island 1967',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3188',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6720','Fiji Geodetic Datum 1986',NULL,NULL,'EPSG','7043','EPSG','8901','EPSG','1094',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6721','Fiji 1956',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3398',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6722','South Georgia 1968',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3529',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6723','Grand Cayman Geodetic Datum 1959',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3185',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6724','Diego Garcia 1969',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3189',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6725','Johnston Island 1961',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3201',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6726','Sister Islands Geodetic Datum 1961',NULL,NULL,'EPSG','7008','EPSG','8901','EPSG','3186',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6727','Midway 1961',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3202',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6728','Pico de las Nieves 1984',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3873',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6729','Pitcairn 1967',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3208',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6730','Santo 1965',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3194',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6731','Viti Levu 1916',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3195',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6732','Marshall Islands 1960',NULL,NULL,'EPSG','7053','EPSG','8901','EPSG','3191',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6733','Wake Island 1952',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3190',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6734','Tristan 1968',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3184',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6735','Kusaie 1951',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3192',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6736','Deception Island',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3204',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6737','Geocentric datum of Korea',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1135',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6738','Hong Kong 1963',NULL,NULL,'EPSG','7007','EPSG','8901','EPSG','1118',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6739','Hong Kong 1963(67)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1118',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6740','Parametry Zemli 1990',NULL,NULL,'EPSG','7054','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6741','Faroe Datum 1954',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3248',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6742','Geodetic Datum of Malaysia 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1151',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6743','Karbala 1979',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','3625',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6744','Nahrwan 1934',NULL,NULL,'EPSG','7012','EPSG','8901','EPSG','4238',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6745','Rauenberg Datum/83',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','2545',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6746','Potsdam Datum/83',NULL,NULL,'EPSG','7004','EPSG','8901','EPSG','2544',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6747','Greenland 1996',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1107',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6748','Vanua Levu 1915',NULL,NULL,'EPSG','7055','EPSG','8901','EPSG','3401',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6749','Reseau Geodesique de Nouvelle Caledonie 91-93',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1174',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6750','ST87 Ouvea',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','2813',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6751','Kertau (RSO)',NULL,NULL,'EPSG','7056','EPSG','8901','EPSG','1309',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6752','Viti Levu 1912',NULL,NULL,'EPSG','7055','EPSG','8901','EPSG','3195',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6753','fk89',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','3248',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6754','Libyan Geodetic Datum 2006',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1143',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6755','Datum Geodesi Nasional 1995',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1122',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6756','Vietnam 2000',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','3328',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6757','SVY21',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1210',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6758','Jamaica 2001',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1128',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6759','NAD83 (National Spatial Reference System 2007)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1511',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6760','World Geodetic System 1966',NULL,NULL,'EPSG','7025','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6761','Croatian Terrestrial Reference System',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1076',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6762','Bermuda 2000',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1047',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6763','Pitcairn 2006',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','3208',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6764','Ross Sea Region Geodetic Datum 2000',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','3558',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6765','Slovenia Geodetic Datum 1996',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1212',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6801','CH1903 (Bern)',NULL,NULL,'EPSG','7004','EPSG','8907','EPSG','1286',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6802','Bogota 1975 (Bogota)',NULL,NULL,'EPSG','7022','EPSG','8904','EPSG','3229',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6803','Lisbon 1937 (Lisbon)',NULL,NULL,'EPSG','7022','EPSG','8902','EPSG','1294',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6804','Makassar (Jakarta)',NULL,NULL,'EPSG','7004','EPSG','8908','EPSG','1316',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6805','Militar-Geographische Institut (Ferro)',NULL,NULL,'EPSG','7004','EPSG','8909','EPSG','1321',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6806','Monte Mario (Rome)',NULL,NULL,'EPSG','7022','EPSG','8906','EPSG','3343',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6807','Nouvelle Triangulation Francaise (Paris)',NULL,NULL,'EPSG','7011','EPSG','8903','EPSG','3694',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6808','Padang 1884 (Jakarta)',NULL,NULL,'EPSG','7004','EPSG','8908','EPSG','1355',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6809','Reseau National Belge 1950 (Brussels)',NULL,NULL,'EPSG','7022','EPSG','8910','EPSG','1347',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6810','Tananarive 1925 (Paris)',NULL,NULL,'EPSG','7022','EPSG','8903','EPSG','3273',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6811','Voirol 1875 (Paris)',NULL,NULL,'EPSG','7011','EPSG','8903','EPSG','1365',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6813','Batavia (Jakarta)',NULL,NULL,'EPSG','7004','EPSG','8908','EPSG','1285',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6814','Stockholm 1938 (Stockholm)',NULL,NULL,'EPSG','7004','EPSG','8911','EPSG','3313',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6815','Greek (Athens)',NULL,NULL,'EPSG','7004','EPSG','8912','EPSG','3254',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6816','Carthage (Paris)',NULL,NULL,'EPSG','7011','EPSG','8903','EPSG','1618',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6817','NGO 1948 (Oslo)',NULL,NULL,'EPSG','7005','EPSG','8913','EPSG','1352',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6818','System of the Unified Trigonometrical Cadastral Network (Ferro)',NULL,NULL,'EPSG','7004','EPSG','8909','EPSG','1306',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6819','Nord Sahara 1959 (Paris)',NULL,NULL,'EPSG','7012','EPSG','8903','EPSG','1366',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6820','Gunung Segara (Jakarta)',NULL,NULL,'EPSG','7004','EPSG','8908','EPSG','1360',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6821','Voirol 1879 (Paris)',NULL,NULL,'EPSG','7011','EPSG','8903','EPSG','1365',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6896','International Terrestrial Reference Frame 2005',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6901','Ancienne Triangulation Francaise (Paris)',NULL,NULL,'EPSG','7027','EPSG','8914','EPSG','1326',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6902','Nord de Guerre (Paris)',NULL,NULL,'EPSG','7027','EPSG','8903','EPSG','1369',1);
INSERT INTO "geodetic_datum" VALUES('EPSG','6903','Madrid 1870 (Madrid)',NULL,NULL,'EPSG','7028','EPSG','8905','EPSG','2366',0);
INSERT INTO "geodetic_datum" VALUES('EPSG','6904','Lisbon 1890 (Lisbon)',NULL,NULL,'EPSG','7004','EPSG','8902','EPSG','1294',0);
